@@ -1,4 +1,3 @@
-
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  * Copyright (c) 2005 Hiroyuki Ikezoe <poincare@ikezoe.net>
@@ -18,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * $Id: scim_tomoe.cpp,v 1.27 2006/11/28 01:42:05 ikezoe Exp $
+ * $Id: scim_tomoe.cpp,v 1.38 2006/12/07 03:59:48 makeinu Exp $
  *
  */
 
@@ -43,7 +42,8 @@
   #include <config.h>
 #endif
 
-#include "intl.h"
+#include <glib/gi18n-lib.h>
+
 #include "scim_tomoe_prefs.h"
 #include "scim_tomoe_prefs_widget.h"
 #include <tomoe-gtk.h>
@@ -56,8 +56,6 @@
 
 #define SCIM_TOMOE_ICON (SCIM_ICONDIR "/scim-tomoe.png")
 
-#define OBJECT_DATA_PREFS_WIN "ScimTomoe::PrefsWin"
-
 using namespace scim;
 
 static void       slot_exit                   (const HelperAgent   *agent,
@@ -70,7 +68,7 @@ static void       slot_update_screen          (const HelperAgent   *agent,
 static void       run                         (const String        &display,
                                                const ConfigPointer &config);
 
-static void       on_char_table_selected      (TomoeCharTable      *table,
+static void       on_candidate_selected       (TomoeWindow         *window,
                                                gpointer             user_data);
 static void       on_space_button_clicked     (GtkButton           *button,
                                                gpointer             user_data);
@@ -84,13 +82,13 @@ static void       on_notebook_switch_page     (GtkNotebook         *notebook,
                                                gpointer             user_data);
 
 static HelperAgent  helper_agent;
-static GtkWidget   *main_window;
+static GtkWidget   *main_window = NULL;
 static gint         main_window_xpos = 0;
 static gint         main_window_ypos = 0;
 
 static ConfigPointer m_config = NULL;
 
-static HelperInfo  helper_info (String ("b1bfe2b4-6930-41b0-8c07-d05bce8c92e2"),
+static HelperInfo  helper_info (String (SCIM_TOMOE_UUID),
                                 "",
                                 String (SCIM_TOMOE_ICON),
                                 "",
@@ -107,7 +105,7 @@ extern "C" {
 
         helper_info.name = String (_("Handwriting recognition"));
         helper_info.description = String (
-            _("An front-end for handwriting recognition engine"));
+            _("A front-end for handwriting recognition engine"));
     }
 
     void scim_module_exit (void)
@@ -134,7 +132,7 @@ extern "C" {
     {
         SCIM_DEBUG_MAIN(1) << "tomoe_LTX_scim_helper_module_run_helper ()\n";
 
-        if (uuid == "b1bfe2b4-6930-41b0-8c07-d05bce8c92e2") {
+        if (uuid == SCIM_TOMOE_UUID) {
             run (display, config);
         }
 
@@ -170,7 +168,7 @@ slot_update_screen (const HelperAgent *agent, int ic,
     if (gdk_display_get_n_screens (gdk_display_get_default ()) > screen) {
         GdkScreen *scr = gdk_display_get_screen (gdk_display_get_default (),
                                                  screen);
-        if (scr)
+        if (scr && main_window)
             gtk_window_set_screen (GTK_WINDOW (main_window), scr);
     }
 }
@@ -179,7 +177,7 @@ static void
 slot_trigger_property (const HelperAgent *agent, int ic,
                        const String &uuid, const String &property)
 {
-    if (property == "/TOMOE") {
+    if (property == "/Tomoe") {
         if (GTK_WIDGET_VISIBLE (main_window)) {
             gtk_window_get_position (GTK_WINDOW (main_window),
                                      &main_window_xpos,
@@ -207,7 +205,8 @@ void run (const String &display, const ConfigPointer &config)
     setenv ("DISPLAY", display.c_str (), 1);
 
     gtk_init (&argc, &argv);
-  
+    tomoe_gtk_init ();
+
     helper_agent.signal_connect_exit (slot (slot_exit));
 	helper_agent.signal_connect_update_screen (slot (slot_update_screen));
     helper_agent.signal_connect_trigger_property (slot (slot_trigger_property));
@@ -216,9 +215,9 @@ void run (const String &display, const ConfigPointer &config)
     GIOChannel *ch = g_io_channel_unix_new (fd);
 
     if (fd >= 0 && ch) {
-        Property prop ("/TOMOE", _("TOMOE"),
+        Property prop ("/Tomoe", _("Tomoe"),
                        SCIM_TOMOE_ICON,
-                       _("Show/Hide TOMOE."));
+                       _("Show/Hide Tomoe."));
 	    PropertyList props;
 
 	    props.push_back (prop);
@@ -245,8 +244,6 @@ void run (const String &display, const ConfigPointer &config)
         g_object_unref (icon);
     }
     gtk_widget_show (window);
-    g_signal_connect (G_OBJECT (window), "response",
-                      G_CALLBACK (gtk_main_quit), NULL);
     main_window = window;
 
     // add software keyboard buttons
@@ -255,7 +252,7 @@ void run (const String &display, const ConfigPointer &config)
 
     separator = gtk_hseparator_new ();
     GtkWidget *hw_page = tomoe_window_get_handwriting_page (TOMOE_WINDOW (tomoe));
-    GtkWidget *button_area = tomoe_stroke_search_get_button_area (TOMOE_STROKE_SEARCH (hw_page));
+    GtkWidget *button_area = tomoe_handwriting_get_button_area (TOMOE_HANDWRITING (hw_page));
     gtk_box_pack_start (GTK_BOX (button_area), separator,
                         FALSE, FALSE, 4);
     gtk_widget_show (separator);
@@ -288,48 +285,39 @@ void run (const String &display, const ConfigPointer &config)
     GtkWidget *notebook = tomoe_window_get_notebook (TOMOE_WINDOW (tomoe));;
     g_signal_connect (G_OBJECT (notebook), "switch-page",
                       G_CALLBACK (on_notebook_switch_page), window);
-    // add hooks
-    GtkWidget *candidates_view = tomoe_stroke_search_get_candidates_view (TOMOE_STROKE_SEARCH (hw_page));
-    g_signal_connect (G_OBJECT (candidates_view), "selected",
-                      G_CALLBACK (on_char_table_selected),
-                      (gpointer) tomoe);
 
     // create preferences widget
     GtkWidget *prefs_widget = scim_tomoe_prefs_widget_new (tomoe, config);
-    g_object_set_data (G_OBJECT (window),
-                       OBJECT_DATA_PREFS_WIN, prefs_widget);
     gtk_widget_show (prefs_widget);
-    bool always_top = SCIM_TOMOE_PREFS_WIDGET (prefs_widget)->config->read (
-        SCIM_TOMOE_CONFIG_WINDOW_ALWAYS_TOP,
-        SCIM_TOMOE_CONFIG_WINDOW_ALWAYS_TOP_DEFAULT);
-    gtk_window_set_keep_above (GTK_WINDOW (window), always_top ? TRUE: FALSE);
 
     // add preference page
-    tomoe_window_append_page (tomoe, prefs_widget, 
-                              gtk_image_new_from_stock (GTK_STOCK_PREFERENCES, GTK_ICON_SIZE_MENU),
-                              _("Preferences for SCIM-TOMOE"));
+    tomoe_window_append_page (
+        tomoe, prefs_widget, 
+        gtk_image_new_from_stock (GTK_STOCK_PREFERENCES, GTK_ICON_SIZE_MENU),
+        _("Preferences for scim-tomoe"));
+
+    // connect to the window's signals
+    g_signal_connect (G_OBJECT (window), "destroy",
+                      G_CALLBACK (gtk_main_quit),
+                      NULL);
+    g_signal_connect (G_OBJECT (window), "selected",
+                      G_CALLBACK (on_candidate_selected),
+                      prefs_widget);
 
     // run
     gtk_main ();
 
-    // quit
-    gtk_widget_destroy (window);
+    tomoe_gtk_quit ();
 }
 
 static void
-on_char_table_selected (TomoeCharTable *table, gpointer user_data)
+on_candidate_selected (TomoeWindow *window, gpointer user_data)
 {
-    TomoeWindow *window = TOMOE_WINDOW (user_data);
-    gpointer object_data = g_object_get_data (G_OBJECT (window),
-                                              OBJECT_DATA_PREFS_WIN);
-    ScimTomoePrefsWidget *prefs_widget = SCIM_TOMOE_PREFS_WIDGET (object_data);
+    ScimTomoePrefsWidget *prefs_widget = SCIM_TOMOE_PREFS_WIDGET (user_data);
 
     if (helper_agent.get_connection_number () < 0) return;
 
-    TomoeChar *t_char = tomoe_char_table_get_selected (table);
-    if (!t_char) return;
-
-    const gchar *str = tomoe_char_get_utf8 (t_char);
+    const gchar *str = tomoe_window_get_selected_char (window);
     if (str && *str) {
         helper_agent.commit_string (-1, "", scim::utf8_mbstowcs (str));
 
@@ -338,8 +326,10 @@ on_char_table_selected (TomoeCharTable *table, gpointer user_data)
             String (SCIM_TOMOE_CONFIG_CLEAR_ON_SELECT),
             SCIM_TOMOE_CONFIG_CLEAR_ON_SELECT_DEFAULT);
         if (value) {
+            TomoeHandwriting *hw;
             TomoeCanvas *canvas;
-            canvas = TOMOE_CANVAS (tomoe_window_get_canvas (window));
+            hw = TOMOE_HANDWRITING (tomoe_window_get_handwriting_page (window));
+            canvas = TOMOE_CANVAS (tomoe_handwriting_get_canvas (hw));
             tomoe_canvas_clear (TOMOE_CANVAS (canvas));
         }
     }
